#import "SampleRootController.h"

#import "OpenFeint/OFControllerLoader.h"
#import "OpenFeint/OFViewHelper.h"
#import "OpenFeint/OpenFeint.h"
#import "OpenFeint/OFWebUIController.h"

#import "SampleUserViewController.h"
#import "SampleFeaturedGamesController.h"
#import "OpenFeint/OFTimeStamp.h"

// temp
#import "OpenFeint/OFHighScoreService.h"
#import "OpenFeint/OFCloudStorageService.h"
#import "OpenFeint/OFAnnouncement.h"

#ifdef __IPHONE_4_1
#import "OpenFeint/OpenFeint+GameCenter.h"
#import "GameKit/GameKit.h"
#endif


#import "OpenFeint/OFXPRequest.h"
#import "OpenFeint/UIButton+OpenFeint.h"

@interface SampleRootController ()
- (void)_push:(NSString*)name;
@end

@implementation SampleRootController

- (void) _push:(NSString*)name
{
	[self.navigationController pushViewController:OFControllerLoader::load(name) animated:YES];
}

- (void)addButtonWithTitle:(NSString*)title andSelector:(SEL)selector
{
	UIButton* b = [UIButton buttonWithType:UIButtonTypeRoundedRect];
	[b setTitleForAllStates:title];
	[b addTarget:self action:selector forControlEvents:UIControlEventTouchUpInside];
	b.frame = CGRectMake(20, mFillY, 280, 37);
	mFillY += 40;
	[self.view addSubview:b];
}

- (void)loadView
{
	mFillY = 20.f;
	UIScrollView* scroll = [[[UIScrollView alloc] initWithFrame:CGRectMake(0, 0, 320, 460)] autorelease];
	self.view = scroll;

	scroll.autoresizingMask = 
		UIViewAutoresizingFlexibleLeftMargin  |
		UIViewAutoresizingFlexibleWidth       |
		UIViewAutoresizingFlexibleRightMargin |
		UIViewAutoresizingFlexibleTopMargin   ;
	self.view.autoresizesSubviews = YES;
	
	scroll.backgroundColor = [UIColor colorWithWhite:0.75 alpha:1.0];
	
	[self addButtonWithTitle:@"Launch OpenFeint Dashboard"     andSelector:@selector(onLaunchDashboard)];
	[self addButtonWithTitle:@"Explore Challenges"             andSelector:@selector(onExploreChallenges)];
	[self addButtonWithTitle:@"Explore Leaderboards"           andSelector:@selector(onExploreLeaderboards)];
	[self addButtonWithTitle:@"Explore Achievements"           andSelector:@selector(onExploreAchivements)];
	[self addButtonWithTitle:@"Explore Social Network Posts"   andSelector:@selector(onExploreSocialNetworkPosts)];
	[self addButtonWithTitle:@"Explore Cloud Storage"          andSelector:@selector(onExploreCloudStorage)];
	[self addButtonWithTitle:@"Explore Current User"           andSelector:@selector(onExploreUser)];
	[self addButtonWithTitle:@"Explore Invites"                andSelector:@selector(onExploreInvites)];
	[self addButtonWithTitle:@"Explore Featured Games"         andSelector:@selector(onExploreFeaturedGames)];
	[self addButtonWithTitle:@"Explore Announcements"          andSelector:@selector(onExploreAnnouncements)];
	[self addButtonWithTitle:@"Explore Launch Dashboard Pages" andSelector:@selector(onExploreLaunchDashboardPages)];
	[self addButtonWithTitle:@"Explore Game Center"            andSelector:@selector(onExploreGameCenterLeaderboard)];
	[self addButtonWithTitle:@"Explore GC Achievements"        andSelector:@selector(onExploreGameCenterAchievements)];
	[self addButtonWithTitle:@"Explore Scores Near Me"		   andSelector:@selector(onExploreScoresNearMe)];
	[self addButtonWithTitle:@"Print Server Timestamp"         andSelector:@selector(onPrintTimestamp)];
	
	
#ifdef __IPHONE_4_1
	gameCenterCommonDelegate = [[GameCenterCommonDelegate alloc] init];
#endif

	[OFTimeStamp setDelegate:self];
	
	scroll.contentSize = OFViewHelper::sizeThatFitsTight(self.view);
	scroll.scrollEnabled = YES;
}

- (void)dealloc
{
#ifdef __IPHONE_4_1
	OFSafeRelease(gameCenterCommonDelegate);
#endif
	[OFTimeStamp setDelegate:nil];
	self.view = nil;
	[super dealloc];
}

- (IBAction) onLaunchDashboard
{
	[OpenFeint launchDashboard];
}

- (IBAction) onExploreChallenges
{
	[self _push:@"SendSampleChallenge"];

}

- (IBAction) onExploreLeaderboards
{
	[self _push:@"SampleLeaderboardList"];
}

- (IBAction) onExploreAchivements
{
	[self _push:@"SampleAchievementList"];
}

- (IBAction) onExploreSocialNetworkPosts
{
	[self _push:@"PostToSocialNetworkSample"];
}

- (IBAction) onExploreCloudStorage
{
	[self _push:@"CloudStorageDemo"];
}

- (IBAction) onExploreInvites
{
	[self _push:@"SampleInvite"];
}

- (IBAction) onExploreAnnouncements
{
	[self _push:@"SampleAnnouncement"];
}

- (IBAction) onExploreUser
{
	SampleUserViewController *controller = [[SampleUserViewController alloc] initWithStyle:UITableViewStyleGrouped];
	[self.navigationController pushViewController:controller animated:YES];
	[controller release];
}

- (IBAction) onExploreFeaturedGames
{
	[self _push:@"SampleFeaturedGames"];
}

- (IBAction) onExploreLaunchDashboardPages
{
	[self _push:@"SampleLaunchDashbaordPages"];
}

- (IBAction) onExploreScoresNearMe
{
	[self _push:@"SampleScoresNearMe"];
}

- (IBAction) onExploreGameCenterLeaderboard 
{
#ifdef __IPHONE_4_1
    if([OpenFeint isUsingGameCenter] && [GKLocalPlayer localPlayer].authenticated) 
	{
        GKLeaderboardViewController *gkController = [GKLeaderboardViewController new];
        gkController.leaderboardDelegate = gameCenterCommonDelegate;
        [self.navigationController presentModalViewController:gkController animated:YES];
        [gkController release];
    }
#endif
}

- (IBAction) onExploreGameCenterAchievements 
{
#ifdef __IPHONE_4_1
    if([OpenFeint isUsingGameCenter] && [GKLocalPlayer localPlayer].authenticated) 
	{
        GKAchievementViewController *gkController = [GKAchievementViewController new];
        gkController.achievementDelegate = gameCenterCommonDelegate;
        [self.navigationController presentModalViewController:gkController animated:YES];
        [gkController release];
    }
#endif
}

- (IBAction) onWebUI {
    OFWebUIController *webui = [[[OFWebUIController alloc] initWithPath:@"debug/index"] autorelease];
    [self.navigationController presentModalViewController:webui animated:YES];
}


- (IBAction) onPrintTimestamp
{
	OFRequestHandle* handle = [OFTimeStamp getServerTime];
	if(!handle)
	{
		[[[[UIAlertView alloc] initWithTitle:@"No OpenFeint" message:@"You have not approved OpenFeint, or OpenFeint is disabled.  Your request will not process." delegate:nil cancelButtonTitle:@"Ok" otherButtonTitles:nil] autorelease] show];
		OFLog(@"Did not get request handle for OFTimeStamp's getServerTime");
	}
}

- (void)didGetServerTime:(OFTimeStamp*)timeStamp
{
	NSLog(@"Time: %@", timeStamp.time);
	NSLog(@"Seconds From Epoch: %d", timeStamp.secondsSinceEpoch);
}

- (void)didFailGetServerTime
{
	NSLog(@"Failed getting server time");
}


- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation
{
	const unsigned int numOrientations = 4;
	UIInterfaceOrientation myOrientations[numOrientations] = { UIInterfaceOrientationPortrait, UIInterfaceOrientationPortraitUpsideDown, UIInterfaceOrientationLandscapeLeft, UIInterfaceOrientationLandscapeRight };
	return [OpenFeint shouldAutorotateToInterfaceOrientation:interfaceOrientation withSupportedOrientations:myOrientations andCount:numOrientations];
}

- (void)willRotateToInterfaceOrientation:(UIInterfaceOrientation)toInterfaceOrientation duration:(NSTimeInterval)duration
{
	[OpenFeint setDashboardOrientation:toInterfaceOrientation];
	[super willRotateToInterfaceOrientation:toInterfaceOrientation duration:duration];
}

@end


#ifdef __IPHONE_4_1
@implementation GameCenterCommonDelegate

- (void)leaderboardViewControllerDidFinish:(GKLeaderboardViewController *)viewController 
{
    [viewController dismissModalViewControllerAnimated:YES];
}

- (void)achievementViewControllerDidFinish:(GKAchievementViewController *)viewController 
{
    [viewController dismissModalViewControllerAnimated:YES];
}
@end

#endif
